Octree

Struct Octree 

pub struct Octree { /* private fields */ }
Octree storing occupancy and vertex positions for Manifold Dual Contouring

Implementations

Source

impl Octree

pub fn build<F: Function + RenderHints + Clone>( b: &BoundShape<'_, F, f32>, settings: &Settings<'_>, ) -> Option<Self>

Builds an octree to the given depth

The shape is evaluated on the region specified by settings.bounds.

Returns None if processing is cancelled by the CancelToken in Settings.

pub fn walk_dual(&self) -> Mesh

Recursively walks the dual of the octree, building a mesh