pub struct Octree { /* private fields */ }Expand description
Octree storing occupancy and vertex positions for Manifold Dual Contouring
Implementations
Sourceimpl Octree
impl Octree
Sourcepub fn build_with_vars<F: Function + RenderHints + Clone>(
shape: &Shape<F>,
vars: &ShapeVars<f32>,
settings: &Settings<'_>,
) -> Option<Self>
pub fn build_with_vars<F: Function + RenderHints + Clone>( shape: &Shape<F>, vars: &ShapeVars<f32>, settings: &Settings<'_>, ) -> Option<Self>
Builds an octree to the given depth, with user-provided variables
The shape is evaluated on the region specified by settings.bounds.
Returns None if processing is cancelled by the CancelToken in
Settings.
Sourcepub fn build<F: Function + RenderHints + Clone>(
shape: &Shape<F>,
settings: &Settings<'_>,
) -> Option<Self>
pub fn build<F: Function + RenderHints + Clone>( shape: &Shape<F>, settings: &Settings<'_>, ) -> Option<Self>
Builds an octree to the given depth
If the shape uses variables other than x, y, z, then
build_with_vars should be used instead (and
this function will return an error).
The shape is evaluated on the region specified by settings.bounds.